pub trait JsSerialize { }Expand description
A trait for types which can be serialized through the js! macro.
Do not try to implement this trait yourself! It’s only meant to be used inside generic code for specifying trait bounds.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".