pub enum EventPhase {
None,
Capturing,
AtTarget,
Bubbling,
}Expand description
Indicates the phase of event flow during event proessing.
Variants
None
No event is currently being processed.
Capturing
The event is being propagated down through the target’s ancestors.
AtTarget
The target is currently processing the event.
Bubbling
The event is propagating back up through the target’s ancestors.