[−][src]Struct stdweb::web::StringMap
Used by the dataset HTML attribute to represent data for custom attributes added to elements.
Methods
impl StringMap[src]
impl StringMappub fn get(&self, key: &str) -> Option<String> | [src] |
Returns a value corresponding to the key.
pub fn insert(&self, key: &str, value: &str) -> Result<(), TODO> | [src] |
Inserts a key-value pair into the map.
pub fn remove(&self, key: &str) | [src] |
Removes a key from the map.
pub fn contains_key(&self, key: &str) -> bool | [src] |
Returns true if the map contains a value for the specified key.