Trait stdweb::web::IElement
[−]
[src]
pub trait IElement: INode + IParentNode { fn class_list(&self) -> TokenList { ... } }
The IElement interface represents an object of a Document.
This interface describes methods and properties common to all
kinds of elements.
Provided Methods
fn class_list(&self) -> TokenList
The Element.classList is a read-only property which returns a live TokenList collection of the class attributes of the element.
Implementors
impl IElement for Elementimpl IElement for HtmlElementimpl IElement for ImageElementimpl IElement for InputElementimpl IElement for TextAreaElementimpl IElement for CanvasElement